@@ -185,17 +185,7 @@ def featureExpressionSig(cluster1, projectionName, featureNumber, alpha, mu=0):
 
 
 def BonferroniCorrectedDifferenceMeans(cluster1, cluster2, alpha, varName, verbose=0, display=True):
-    """
 
-    Creates Bonferroni corrected Confidence intervals for the difference of the means of cluster1 and cluster2
-    :param display: Whether to display CIs or not
-    :param verbose: Whether to print out genes and CIs or not. 0 for print out. not 0 for no printing.
-    :param cluster1: Anndata containing cluster1 cells
-    :param cluster2: Anndata containing cluster2 cells
-    :param alpha: Confidence value
-    :param varName: What column in var to use for gene names
-    :return: A dataframe of genes as index with their respective confidence intervals in columns low and high.
-    """
     dimensionality = cluster1.shape[1]
     print("weird")
 
